export declare enum FontType {
    all = 0,
    fixed = 1,
    variable = 2
}
export declare const fonts: any;
export declare const fontVariable: string[];
export declare const fontFixed: string[];
export declare class Detector {
    private baseFonts;
    private body;
    private span;
    private readonly testString;
    private readonly testSize;
    constructor();
    /**
     * Adds the requested font to the document body.  It checks to see if the
     * width or height of the testString has changed when compared to the
     * computed baseFonts.  If there is a change, then detect returns
     * true.  If all baseFonts are checked and there is no change, then the
     * font is not available.
     * @param fontName {string} the name of the font to check in the browser
     * @return true if the font is available, otherwise false.
     */
    detect(fontName: string): boolean;
}
/**
 * A convenience function that checks a base list of possible fonts and returns
 * the list that was found.  It uses the file "fontlist.json" to list the fonts
 * that will be used by default.  Expand this list to expand default lookup coverage.
 * The caller can also pass a list of fonts and override the default "fontlist.json"
 * @param fontList {string[]} a custom list of fonts that will be used for the
 * search list.  If empty the "fontlist.json" will be used.
 * @param fontType {FontType} two types of fonts: fixed and variable.  By default
 * all types will be searched.  This allows the caller to segregate types if
 * desired.
 * @return {string[]} an array of strings containing valid fonts.
 */
export declare function getFontList(fontList?: string[], fontType?: FontType): string[];
